<?php declare(strict_types=1);

namespace Res\ResChannableConnector\Migration;

use Doctrine\DBAL\Connection;
use Exception;
use Shopware\Core\Defaults;
use Shopware\Core\Framework\Migration\MigrationStep;
use Shopware\Core\Framework\Uuid\Uuid;

class Migration1620640853ResChannableConfig extends MigrationStep
{
    public function getCreationTimestamp(): int
    {
        return 1620640853;
    }

    public function update(Connection $connection): void
    {
        $sql = <<<SQL
CREATE TABLE IF NOT EXISTS `reschannable_config` (
  `id` binary(16) NOT NULL,
  `configuration_key` varchar(255) COLLATE utf8mb4_unicode_ci NOT NULL,
  `configuration_value` json NOT NULL,
  `sales_channel_id` binary(16) NOT NULL,
  `language_id` binary(16) NOT NULL,
  `created_at` datetime(3) NOT NULL,
  `updated_at` datetime(3) DEFAULT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `uniq.reschannable_config.key` (`configuration_key`,`sales_channel_id`,`language_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci
SQL;

        $connection->executeStatement($sql);

        $this->copyDefaultConfigurationIfExists($connection);
    }

    public function updateDestructive(Connection $connection): void
    {
        // implement update destructive
    }

    /**
     * Copy default configuration to Channable config table if necessary
     */
    private function copyDefaultConfigurationIfExists(Connection $connection): void
    {
        $sql = <<<SQL
SELECT LOWER(HEX(`id`)) AS `id`, 
configuration_key, configuration_value, 
LOWER(HEX(`sales_channel_id`)) AS `sales_channel_id`, 
created_at, updated_at
FROM `system_config` 
WHERE `configuration_key` LIKE '%ResChannableConnector.settings%'
AND `sales_channel_id` IS NOT NULL
SQL;

        $configs = $connection->fetchAllAssociative($sql);
        if (empty($configs)) {
            return;
        }

        foreach ($configs as $config) {
            $salesChannelId = $config['sales_channel_id'];
            if (!$salesChannelId) {
                $salesChannelId = $this->getDefaultSalesChannelId($connection);
            }

            $sql = 'SELECT LOWER(HEX(`language_id`)) AS `language_id` FROM `sales_channel` WHERE `id` = UNHEX(?)';
            $languageId = $connection->fetchOne($sql, [$salesChannelId]);
            if (!$languageId) {
                continue;
            }

            $data = $config;
            $data['language_id'] = Uuid::fromHexToBytes($languageId);
            $data['sales_channel_id'] = Uuid::fromHexToBytes($salesChannelId);
            try {
                $connection->insert('reschannable_config', $data);
            } catch (Exception $ignored) {
                // Do nothing here as configuration already exists
            }
        }
    }

    private function getDefaultSalesChannelId(Connection $connection)
    {
        $sql = 'SELECT LOWER(HEX(`id`)) AS `id` FROM `sales_channel` WHERE `type_id` = UNHEX(?) AND `active` = \'1\'';

        return $connection->fetchOne($sql, [Defaults::SALES_CHANNEL_TYPE_STOREFRONT]);
    }

}
