const ApiService = Shopware.Classes.ApiService;

class ResChannableConnectorConfigService extends ApiService {
    constructor(httpClient, loginService, apiEndpoint = 'reschannable') {
        super(httpClient, loginService, apiEndpoint);
    }

    getValues(salesChannelId, languageId, additionalParams = {}, additionalHeaders = {}) {
        return this.httpClient
            .get(`_action/reschannable/get-config-values`, {
                params: { salesChannelId, languageId, ...additionalParams },
                headers: this.getBasicHeaders(additionalHeaders)
            })
            .then((response) => {
                return ApiService.handleResponse(response);
            });
    }

    saveValues(values, salesChannelId, languageId, additionalParams = {}, additionalHeaders = {}) {
        return this.httpClient
            .post(`_action/reschannable/save-config-values`,
                values,
                {
                    params: { salesChannelId, languageId, ...additionalParams },
                    headers: this.getBasicHeaders(additionalHeaders)
                })
            .then((response) => {
                return ApiService.handleResponse(response);
            });
    }

    batchSave(values, additionalParams = {}, additionalHeaders = {}) {
        return this.httpClient
            .post(`_action/reschannable/batch-save-config-values`,
                values,
                {
                    params: { ...additionalParams },
                    headers: this.getBasicHeaders(additionalHeaders)
                })
            .then((response) => {
                return ApiService.handleResponse(response);
            });
    }
}

export default ResChannableConnectorConfigService;
