import template from './res-channableconnector-artconf.html.twig';

const { Component, Mixin, Context } = Shopware;
const { EntityCollection, Criteria } = Shopware.Data;
const { mapApiErrors } = Shopware.Component.getComponentHelper();
const types = Shopware.Utils.types;

Component.register('res-channableconnector-artconf', {
    template,

    inject: [
        'repositoryFactory'/*,
        'conditionDataProviderService',
        'childAssociationField'*/
    ],

    name: 'ResChannableConnectorArtConf',

    inheritAttrs: true,
    mixins: [
        Mixin.getByName('placeholder')
    ],

    data() {
        return {
            priceRuleCollection: this.createPriceRuleCollection()
            /*propertyGroups: null*/
        };
    },

    props: {
        /*propertyGroupIds: {
            type: Array,
            required: false,
            default() {
                return [];
            }
        },
        ids: {
            type: Array,
            required: false,
            default() {
                return [];
            }
        },*/
        actualConfigData: {
            type: Object,
            required: true
        },
        allConfigs: {
            type: Object,
            required: true
        },
        selectedSalesChannelId: {
            type: String,
            required: false,
            default: null
        },
        isLoading: {
            type: Boolean,
            required: true
        },
        priceRuleIds: {
            type: Object,
            required: false,
            default: null
        },
        /*propertyGroup: {
            type: Object,
            required: false,
            default: null
        }

        ,*/
        context: {
            type: Object,
            required: false,
            default() {
                return Context.api;
            }
        }
    },

    computed: {
        /*...mapApiErrors('propertyGroup', ['name']),

        propertyGroupsCriteria() {
            const criteria = new Criteria();
            criteria.addFilter(Criteria.not('and', [Criteria.equals('id', this.propertyGroup.id)]));
            return criteria;
        },
        conditionClasses() {
            return {
                'has--error': this.hasError,
                'is--disabled': this.hasNoComponent
            };
        },

        ...mapApiErrors('condition', ['type']),

        currentError() {
            return this.conditionValueOperatorError || this.conditionValuePropertyGroupIdsError;
        },

        hasError() {
            return this.currentError !== null;
        },

        valueErrorPath() {
            return `${this.condition.getEntityName()}.${this.condition.id}.value`;
        },

        value() {
            return this.condition.value;
        },

        hasNoComponent() {
            const component = this.conditionDataProviderService.getComponentByCondition(this.condition);

            return component === 'sw-condition-not-found';
        },

        propertyGroupRepository() {
            return this.repositoryFactory.create('property_group');
        },*/

        ruleRepository() {
            return this.repositoryFactory.create('rule');
        },

        priceRuleCriteria() {
            const criteria = new Criteria(1, 500);
            criteria.addFilter(
                Criteria.multi('OR', [
                    Criteria.contains('rule.moduleTypes.types', 'price'),
                    Criteria.equals('rule.moduleTypes', null),
                ]),
            );

            return criteria;
        },

        context() {
            const context = { ...Context.api, inheritance: true };

            return context;
        }

        /*operators() {
            return this.conditionDataProviderService.getOperatorSet('multiStore');
        },*/

        /*propertyGroupIds: {
            get() {
                this.ensureValueExist();
                return this.condition.value.propertyGroupIds || [];
            },
            set(propertyGroupIds) {
                this.ensureValueExist();
                this.condition.value = { ...this.condition.value, propertyGroupIds };
            }
        },

        ...mapApiErrors('condition', ['value.operator', 'value.propertyGroupIds'])*/
    },

    created() {
        this.createdComponent();
    },

    watch: {
        /*value() {
            if (this.hasError) {
                this.$store.commit('error/removeApiError', { expression: this.valueErrorPath });
            }
        }
        propertyGroup() {
            if (this.propertyGroup) {
                this.loadPropertyGroups();
            }
        }*/

        priceRuleIds() {
            if (this.priceRuleIds) {
                this.loadPriceRules();
            }
        }
    },

    methods: {

        loadPriceRules() {
            if (types.isEmpty(this.priceRuleIds)) {
                this.priceRuleCollection = this.createPriceRuleCollection();
                return;
            }

            const ruleRepository = this.repositoryFactory.create('rule');
            const criteria = (new Criteria(1, 500)).addFilter(Criteria.equalsAny('id', this.priceRuleIds));

            return ruleRepository.search(criteria).then((res) => {
                this.priceRuleCollection = res;
            });
        },

        createPriceRuleCollection() {
            return new EntityCollection('/rule', 'rule', Context.api);
        },

        onChangePriceRules(priceRules) {
            this.priceRuleIds = [];

            priceRules.forEach((priceRule) => {
                this.priceRuleIds.push(priceRule.id);
            });

            this.loadPriceRules();
        },

        /*loadPropertyGroups() {
            if (types.isEmpty(this.propertyGroup.propertyGroupIds)) {
                this.propertyGroups = this.createPropertyGroupCollection();
                return;
            }

            const propertyGroupRepository = this.repositoryFactory.create('property_group');
            const criteria = (new Criteria()).addFilter(Criteria.equalsAny('id', this.propertyGroup.propertyGroupIds));

            propertyGroupRepository.search(criteria, Context.api).then((properties) => {
                this.propertyGroups = properties;
            });
        },

        onChangePropertyGroups(propertyGroups) {
            this.propertyGroup.propertyGroupIds = [];

            propertyGroups.forEach((group) => {
                this.propertyGroup.propertyGroupIds.push(group.id);
            });
        },

        createPropertyGroupCollection() {
            return new EntityCollection('/property_group', 'property_group', Context.api, new Criteria());
        },

        checkBoolFieldInheritance(value) {
            return typeof value !== 'boolean';
        },

        loadData() {
            this.isLoading = true;

            return this.repositoryFactory.search(this.criteria, this.context).then((result) => {
                this.displaySearch(result);

                this.isLoading = false;

                return result;
            });
        },*/

        /*updateIds(collection) {
            this.collection = collection;
            this.$emit('change', collection);
        }*/

        /*onCreateBefore() {
            this.$emit('create-before');
        },

        onCreateAfter() {
            this.$emit('create-after');
        },

        onDeleteCondition() {
            this.$emit('condition-delete');
        },*/

        /*createPropertyGroupCollection() {
            return new EntityCollection('/property-group', 'property_group', Context.api);
        },*/

        createdComponent() {
            if (!this.priceRuleIds && !types.isEmpty(this.actualConfigData["ResChannableConnector.settings.priceRules"]) ) {
                this.priceRuleIds = this.actualConfigData["ResChannableConnector.settings.priceRules"];
            }

            if (this.priceRuleIds) {
                this.loadPriceRules();
            }

            /*if (this.propertyGroup) {
                this.loadPropertyGroups();
            }

            if ( typeof this.$refs.propertyGroupSelect !== "undefined" ) {
                // this.$refs.propertyGroupSelect.resetResultCollection();
            }*/

            /*const criteria = new Criteria();
            criteria.setIds(this.$props.actualConfigData['ResChannableConnector.settings.properties']);

            this.propertyGroupRepository.search(
                criteria,
                Context.api
            ).then((responseAssoc) => {
            });

            this.$refs.propertyGroupSelect.resetResultCollection();*/

            /*this.mailTemplateSalesChannels = this.createSalesChannelCollection();
            this.mailTemplate.salesChannels.forEach((salesChannelAssoc) => {
                this.mailTemplateSalesChannels.push(salesChannelAssoc.salesChannel);
            });*/

            /*this.propertyGroups = new EntityCollection(
                this.propertyGroupRepository.route,
                this.propertyGroupRepository.entityName,
                this.context
            );

            if (this.propertyGroupIds.length <= 0) {
                return Promise.resolve();
            }

            const criteria = new Criteria();
            criteria.setIds(this.propertyGroupIds);

            return this.propertyGroupRepository.search(criteria, this.context).then((properties) => {
                this.propertyGroups = properties;
                return this.propertyGroups;
            });*/
        },

        /*onChangePropertyGroups(propertyGroups) {
            this.propertyGroups = propertyGroups;
            this.$emit('change', propertyGroups.getIds());
        },

        setPropertyGroupIds(properties) {
            this.propertyGroupIds = properties.getIds();
            this.propertyGroups = properties;
        },*/
    }

});