import template from './res-channable-connector.html.twig';
import './res-channable-connector.scss';

const { Defaults, Component, Context } = Shopware;
const { Criteria, EntityCollection } = Shopware.Data;
const types = Shopware.Utils.types;

Component.register('res-channable-connector', {
    template,

    inject: [
        'ResChannableConnectorAutoConnectService',
        'ResChannableConnectorConfigService',
        'repositoryFactory',
        'systemConfigApiService'
    ],

    data() {
        return {
            isLoading: false,
            isSaveSuccessful: false,
            config: null,
            allConfigs: {},
            selectedSalesChannelId: null,
            selectedLanguageId: null,
            salesChannels: [],
            language: []
        }
    },

    metaInfo() {
        return {
            title: this.$createTitle()
        };
    },

    watch: {

        selectedLanguageId: {
            handler(languageId) {
                if (!languageId) {
                    return;
                }

                this.createdComponent();
            }
        },
    },

    computed: {

        /*propertyGroupRepository() {
            return this.repositoryFactory.create('property_group');
        },*/

        configKey() {
            if (!this.selectedSalesChannelId || !this.selectedLanguageId) {
                return null;
            }

            return this.selectedSalesChannelId + '-' + this.selectedLanguageId;
        },

        actualConfigData: {
            get() {
                return this.allConfigs[this.configKey];
            },
            set(config) {
                this.allConfigs = {
                    ...this.allConfigs,
                    [this.configKey]: config
                };
            }
        },

        languageRepository() {
            return this.repositoryFactory.create('language');
        },

        salesChannelRepository() {
            return this.repositoryFactory.create('sales_channel');
        },

        resChannableConfigRepository() {
            return this.repositoryFactory.create('reschannable_config');
        }
    },

    created() {
        this.createdComponent();
    },

    methods: {

        createdComponent() {
            if ((this.selectedSalesChannelId && this.selectedLanguageId)) {
                this.isLoading = true;
                this.allConfigs = {};
                this.readAll().then((values) => {
                    this.actualConfigData = values;
                    this.isLoading = false;
                });

                if (this.actualConfigData !== undefined && this.$refs.channablePriceRules !== undefined) {
                    this.$refs.channablePriceRules.priceRuleIds = this.actualConfigData["ResChannableConnector.settings.priceRules"];
                }
            }

            if (!this.salesChannels.length) {
                this.isLoading = true;

                const criteria = new Criteria();
                criteria.addAssociation('languages');
                criteria.addAssociation('domains');
                criteria.addFilter(Criteria.equalsAny('typeId', [
                    Defaults.storefrontSalesChannelTypeId,
                    Defaults.apiSalesChannelTypeId
                ]));

                this.salesChannelRepository.search(criteria, Context.api).then(res => {
                    res.add({
                        id: null,
                        translated: {
                            name: this.$tc('sw-sales-channel-switch.labelDefaultOption')
                        }
                    });

                    this.salesChannels = res;

                    this.isLoading = false;
                }).finally(() => {
                    this.isLoading = false;
                });
            }

            /*if ( typeof this.$refs.configComponent !== "undefined" && this.$refs.configComponent.allConfigs.null['ResChannableConnector.settings.properties'] ) {

                const criteria = new Criteria();
                criteria.setIds(this.$refs.configComponent.allConfigs.null['ResChannableConnector.settings.properties']);

                this.propertyGroupRepository.search(
                    criteria,
                    Context.api
                ).then((responseAssoc) => {


                });
            }*/

            // this.$refs.propertyGroupSelect.resetResultCollection();

            /*if ( typeof this.$refs.propertyGroupSelect !== "undefined" ) {
                // this.$refs.propertyGroupSelect.resetResultCollection();
            }*/
        },

        async readAll() {
            return await this.ResChannableConnectorConfigService.getValues(this.selectedSalesChannelId, this.selectedLanguageId);
        },

        onSave() {
            this.save();
        },

        save() {
            this.isLoading = true;
            this.isSaveSuccessful = false;

            console.log('page save');
            console.log(this.allConfigs);

            this.actualConfigData["ResChannableConnector.settings.priceRules"] = this.$refs.channablePriceRules.priceRuleIds;

            console.log(this.allConfigs);

            this.ResChannableConnectorConfigService.batchSave(this.allConfigs).then((res) => {
                this.isLoading = false;
                this.isSaveSuccessful = true;
                this.createNotificationSuccess({
                    title: this.$tc('res-channable-connector.settingForm.titleSuccess'),
                    message: this.$tc('res-channable-connector.settingForm.configSaved')
                });

                if (res) {
                    this.actualConfigData = res;
                }
            }).catch((e) => {
                this.isSaveSuccessful = false;
                this.isLoading = false;
            });
        },

        onSelectedSalesChannel(salesChannelId) {
            this.language = [];
            this.salesChannelDomains = [];
            if (this.salesChannels === undefined || salesChannelId === null) {
                this.onSelectedLanguage(null);
                return;
            }

            let selectedChannel = this.salesChannels.find(item => item.id === salesChannelId);
            if (selectedChannel) {

                this.selectedSalesChannelId = salesChannelId;

                this.onSelectedLanguage(selectedChannel.languageId);
                selectedChannel.languages.forEach((language) => {
                    this.language.push({
                        name: language.name,
                        label: language.name,
                        value: language.id
                    });
                });
            }
        },

        onSelectedLanguage(languageId) {
            this.selectedLanguageId = languageId;
            this.createdComponent();
        },
    }
});