<?php declare(strict_types=1);

namespace Res\ResChannableConnector\Setting\Service;

use Shopware\Core\Framework\Context;
use Shopware\Core\Framework\DataAbstractionLayer\Search\Criteria;
use Shopware\Core\Framework\DataAbstractionLayer\EntityRepository;
use Shopware\Core\Framework\DataAbstractionLayer\Search\Filter\EqualsFilter;
use Shopware\Core\System\User\Aggregate\UserAccessKey\UserAccessKeyCollection;
use Shopware\Core\System\User\Aggregate\UserAccessKey\UserAccessKeyEntity;
use Shopware\Core\System\User\UserEntity;

class AutoConnectService implements AutoConnectServiceInterface
{
    /**
     * @var EntityRepository
     */
    private $salesChannelRepository;

    /**
     * @var EntityRepository
     */
    private $userRepository;

    public function __construct(
        EntityRepository $salesChannelRepository,
        EntityRepository $userRepository
    )
    {
        $this->salesChannelRepository = $salesChannelRepository;
        $this->userRepository = $userRepository;
    }

    public function getUrl(string $salesChannelId, string $languageId): string
    {
        $apiKey = $this->getApiKey();

        $appUrl = $_SERVER['APP_URL'];

        # Check for https
        /*if ( stripos($appUrl,'http://') !== false && ( !isset($_SERVER['HTTP_X_FORWARDED_PROTO']) || $_SERVER['HTTP_X_FORWARDED_PROTO'] != 'https' ) ) {

            try {
                $appUrlSecure = str_replace('http://', 'https://', $appUrl);
                $headers = get_headers($appUrlSecure);

                if ( $headers && (stripos($headers[0], '301') !== false || stripos($headers[0], '200')) ) {
                    $appUrl = $appUrlSecure;
                }
            } catch ( \Exception $exception ) {
                # Skip if headers are not accessible
            }
        }

        # Get redirected url
        $ch = curl_init();
        curl_setopt($ch, CURLOPT_URL, $appUrl);
        curl_setopt($ch, CURLOPT_HEADER, true);
        curl_setopt($ch, CURLOPT_FOLLOWLOCATION, true);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);

        $headers = curl_exec($ch);

        $redirectedAppUrl = curl_getinfo($ch, CURLINFO_EFFECTIVE_URL);

        if ( $redirectedAppUrl ) {
            $appUrl = $redirectedAppUrl;
        }*/

        $url = 'https://app.channable.com/connect/shopware_plugin.html?';

        $url .= 'url='.$appUrl;
        $url .= '&shop='.$salesChannelId;
        $url .= '&lang='.$languageId;
        $url .= '&version=shopware_6';
        $url .= '&username=ChannableApiUser';
        $url .= '&api_key='.$apiKey;

        return $url;
    }

    /**
     * Get api user key
     */
    private function getApiKey(): string
    {
        $context = Context::createDefaultContext();

        # Check user exist
        $criteria = new Criteria();
        $criteria->addFilter(new EqualsFilter('username', 'ChannableApiUser'));
        $criteria->addAssociation('accessKeys');

        /** @var UserEntity $user */
        $user = $this->userRepository->search($criteria,$context)->first();

        /** @var UserAccessKeyCollection $accessKeys */
        $accessKeys = $user->getAccessKeys();

        /** @var UserAccessKeyEntity $accessKey */
        $accessKeyEnt = $accessKeys->first();

        return $accessKeyEnt->getAccessKey();
    }

}